@@ -8,6 +8,7 @@ from typing import Union
 from dataconf.exceptions import MalformedConfigException
 from dataconf.exceptions import MissingTypeException
 from dataconf.exceptions import TypeConfigException
+from dataconf.exceptions import UnexpectedKeysException
 from dateutil.relativedelta import relativedelta
 from pyhocon import ConfigFactory
 from pyhocon import HOCONConverter
@@ -50,6 +51,12 @@ def __parse(value: any, clazz, path):
                     val = f.default
             fs[f.name] = __parse(val, f.type, f"{path}.{f.name}")
 
+        unexpected_keys = value.keys() - fs.keys()
+        if len(unexpected_keys) > 0:
+            raise UnexpectedKeysException(
+                f"unexpected keys {', '.join(unexpected_keys)} detected for type {clazz} at {path}"
+            )
+
         return clazz(**fs)
 
     origin = get_origin(clazz)
@@ -57,15 +64,19 @@ def __parse(value: any, clazz, path):
 
     if origin is list:
         if len(args) != 1:
-            raise MissingTypeException("excepted list with type information: List[?]")
-        return [__parse(v, args[0], f"{path}[]") for v in value]
+            raise MissingTypeException("expected list with type information: List[?]")
+        if value is not None:
+            return [__parse(v, args[0], f"{path}[]") for v in value]
+        return None
 
     if origin is dict:
         if len(args) != 2:
             raise MissingTypeException(
-                "excepted dict with type information: Dict[?, ?]"
+                "expected dict with type information: Dict[?, ?]"
             )
-        return {k: __parse(v, args[1], f"{path}.{k}") for k, v in value.items()}
+        if value is not None:
+            return {k: __parse(v, args[1], f"{path}.{k}") for k, v in value.items()}
+        return None
 
     if origin is Union:
         left, right = args
